@@ -912,20 +912,59 @@ loop0                                     0"""
         self.assertEqual(expected, result)
 
     @mock.patch('os_brick.privileged.rootwrap.execute', return_value=('', ''))
-    def test_is_multipath_running_default_executor(self, mock_exec):
+    def test_is_multipath_running(self, mock_exec):
         res = linuxscsi.LinuxSCSI.is_multipath_running(False, None, mock_exec)
         self.assertTrue(res)
         mock_exec.assert_called_once_with(
             'multipathd', 'show', 'status', run_as_root=True, root_helper=None)
 
+    @mock.patch.object(linuxscsi, 'LOG')
     @mock.patch('os_brick.privileged.rootwrap.execute')
-    def test_is_multipath_running_failure_exit_code_0(self, mock_exec):
+    def test_is_multipath_running_failure(
+        self, mock_exec, mock_log
+    ):
+        mock_exec.side_effect = putils.ProcessExecutionError()
+        self.assertRaises(putils.ProcessExecutionError,
+                          linuxscsi.LinuxSCSI.is_multipath_running,
+                          True, None, mock_exec)
+        mock_log.error.assert_called_once()
+
+    @mock.patch.object(linuxscsi, 'LOG')
+    @mock.patch('os_brick.privileged.rootwrap.execute')
+    def test_is_multipath_running_failure_exit_code_0(
+        self, mock_exec, mock_log
+    ):
         mock_exec.return_value = ('error receiving packet', '')
         self.assertRaises(putils.ProcessExecutionError,
                           linuxscsi.LinuxSCSI.is_multipath_running,
                           True, None, mock_exec)
         mock_exec.assert_called_once_with(
             'multipathd', 'show', 'status', run_as_root=True, root_helper=None)
+        mock_log.error.assert_called_once()
+
+    @mock.patch.object(linuxscsi, 'LOG')
+    @mock.patch('os_brick.privileged.rootwrap.execute')
+    def test_is_multipath_running_failure_not_enforcing_multipath(
+        self, mock_exec, mock_log
+    ):
+        mock_exec.side_effect = putils.ProcessExecutionError()
+        res = linuxscsi.LinuxSCSI.is_multipath_running(False, None, mock_exec)
+        mock_exec.assert_called_once_with(
+            'multipathd', 'show', 'status', run_as_root=True, root_helper=None)
+        self.assertFalse(res)
+        mock_log.error.assert_not_called()
+
+    @mock.patch.object(linuxscsi, 'LOG')
+    @mock.patch('os_brick.privileged.rootwrap.execute')
+    def test_is_multipath_running_failure_not_enforcing_exit_code_0(
+        self, mock_exec, mock_log
+    ):
+        mock_exec.return_value = ('error receiving packet', '')
+        res = linuxscsi.LinuxSCSI.is_multipath_running(False, None, mock_exec)
+        mock_exec.assert_called_once_with(
+            'multipathd', 'show', 'status', run_as_root=True, root_helper=None)
+        self.assertFalse(res)
+        mock_log.error.assert_not_called()
 
     def test_get_device_info(self):
         ret = "[1:1:0:0] disk Vendor Array 0100 /dev/adevice\n"
@@ -1192,36 +1231,6 @@ loop0                                     0"""
         self.linuxscsi.multipath_del_path('/dev/sda')
         self.assertEqual(['multipathd del path /dev/sda'], self.cmds)
 
-    @ddt.data({'con_props': {}, 'dev_info': {'path': mock.sentinel.path}},
-              {'con_props': None, 'dev_info': {'path': mock.sentinel.path}},
-              {'con_props': {'device_path': mock.sentinel.device_path},
-               'dev_info': {'path': mock.sentinel.path}})
-    @ddt.unpack
-    def test_get_dev_path_device_info(self, con_props, dev_info):
-        self.assertEqual(mock.sentinel.path,
-                         self.linuxscsi.get_dev_path(con_props, dev_info))
-
-    @ddt.data({'con_props': {'device_path': mock.sentinel.device_path},
-               'dev_info': {'path': None}},
-              {'con_props': {'device_path': mock.sentinel.device_path},
-               'dev_info': {'path': ''}},
-              {'con_props': {'device_path': mock.sentinel.device_path},
-               'dev_info': {}},
-              {'con_props': {'device_path': mock.sentinel.device_path},
-               'dev_info': None})
-    @ddt.unpack
-    def test_get_dev_path_conn_props(self, con_props, dev_info):
-        self.assertEqual(mock.sentinel.device_path,
-                         self.linuxscsi.get_dev_path(con_props, dev_info))
-
-    @ddt.data({'con_props': {'device_path': ''}, 'dev_info': {'path': None}},
-              {'con_props': {'device_path': None}, 'dev_info': {'path': ''}},
-              {'con_props': {}, 'dev_info': {}},
-              {'con_props': {}, 'dev_info': None})
-    @ddt.unpack
-    def test_get_dev_path_no_path(self, con_props, dev_info):
-        self.assertEqual('', self.linuxscsi.get_dev_path(con_props, dev_info))
-
     @ddt.data(('/dev/sda', '/dev/sda', False, True, None),
               # This checks that we ignore the was_multipath parameter if it
               # doesn't make sense (because the used path is the one we are
